use std::{env, process::exit};

use strum::{EnumIter, IntoEnumIterator};

use crate::{decoding::{decode_json, CctweakedMessage}, networking::{get_json, send_json}};

#[derive(Debug, EnumIter)]
enum KnownArguments {
    Help,
    Send,
    Recieve,
    Wrong,
}

const URL: &str = "https://dixxe.top/cctweaked-beta"; 

fn gratefull_exit() {
    println!("Please provide correct arguments or look at --help");
    exit(0)
}

pub fn process_cli_args() {
    let args: Vec<_> = env::args().collect();

    if args.len() < 2 {
        gratefull_exit();
    }
    // Removing execution path probably.
    let args = &args[1..];

    let arg_type = match args[0].as_str() {
        "help" => KnownArguments::Help,
        "--help" => KnownArguments::Help,
        "-h" => KnownArguments::Help,
        "send" => KnownArguments::Send,
        "recieve" => KnownArguments::Recieve,
        _ => KnownArguments::Wrong,
    };

    match arg_type {
        KnownArguments::Help => process_help(args),
        KnownArguments::Send => process_send(args),
        KnownArguments::Recieve => process_recieve(args),
        KnownArguments::Wrong => gratefull_exit(),
    };
}

fn process_help(_: &[String]) {
    println!("All posible arguments:");
    for argument in KnownArguments::iter() {
        println!("{:?}", argument);
    }
}
fn process_send(args: &[String]) {
    let inputed_json: CctweakedMessage = serde_json::from_str(&args[1])
        .expect("Wrong CCTweaked Message. Try to encapsulate it in '' ");

    let resp = send_json(URL.to_owned(), inputed_json)
        .expect("Failed to send json");

    println!("{}, {}", resp.status(), resp.text().unwrap());

}
fn process_recieve(_: &[String]) {

    let resp = get_json(URL.to_owned())
    .expect("Expected a value, got error.");

    println!("{:#?}", decode_json(resp));

}

